@@ -1,6 +1,5 @@
 mlmfit <-
-function(jm1,data,Maxiter=200) {
-  data_surv=data
+function(jm1,data_surv,Maxiter=200) {
   res1<-design_frailtyHL(jm1[[3]],data=data)
   kkk<-length(res1[[4]])
   if (length(res1[[4]])==1) res<-mlmfit1(jm1=jm1,data_surv,Maxiter=Maxiter)
